==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_projversionpage.php <==
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="4"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>Software Versions</b></font></td>
</tr>
<tr bgcolor="<?= $color_4 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b>Version</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Description</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Added By</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Added On</b></font></td>
<tr>
<? if(!empty($version_list)) { 
       while(list(,$version) = @each($version_list)) {
		if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
        ?>
<tr bgcolor="<?= $row_bgcolor ?>">
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= $version["version_code"] ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= $version["description"] ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= getMemberName($version["created_by"]) ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= $version["date_created"] ?></font></td>
</tr>
<? } } else { ?>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><i>There are no versions of this software available for download</i></font></td>
</tr>
<? } ?>
<tr>
<td colspan="4" align="center"><hr width="80%" size="2" noshade></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>Add a New Version</b></font></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2">Versions must be added in order. The last version added will always be assumed as the most recent version. If versions are not added in the correct order they will not show up in the correct order when they are displayed to users. Versions can not be removed once they have been added.</font></td>
</tr>
<form method=post action="/project/<?= $project_name ?>/projversion.php">
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Version Code:</b></font></td>
<td colspan="3" width="100%"><input type="text" name="version_code" maxsize="10"><font face="<?= $font_1 ?>" size="2"><i>&nbsp; (Example: 1.0.3b)</i></font></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
<td colspan="3" width="100%"><textarea rows="5" cols="40" name="description"></textarea></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td colspan="3"><input type="submit" value="Add Version"></td>
</tr>
</form>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_projversionpage.php <==
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="4"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>Software Versions</b></font></td>
</tr>
<tr bgcolor="<?= $color_4 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b>Version</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Description</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Added By</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Added On</b></font></td>
<tr>
<? if(!empty($version_list)) { 
       while(list(,$version) = @each($version_list)) {
		if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
        ?>
<tr bgcolor="<?= $row_bgcolor ?>">
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= $version["version_code"] ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= $version["description"] ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= getMemberName($version["created_by"]) ?></font></td>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><?= date("m/d/Y",strtotime($version["date_created"])) ?></font></td>
</tr>
<? } } else { ?>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><i>There are no versions of this software available for download</i></font></td>
</tr>
<? } ?>
<tr>
<td colspan="4" align="center"><hr width="80%" size="2" noshade></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>Add a New Version</b></font></td>
</tr>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2">Versions must be added in order. The last version added will always be assumed as the most recent version. If versions are not added in the correct order they will not show up in the correct order when they are displayed to users. Versions can not be removed once they have been added.</font></td>
</tr>
<form method=post action="/project/<?= $project_name ?>/projversion.php">
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Version Code:</b></font></td>
<td colspan="3" width="100%"><input type="text" name="version_code" maxsize="10"><font face="<?= $font_1 ?>" size="2"><i>&nbsp; (Example: 1.0.3b)</i></font></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
<td colspan="3" width="100%"><textarea rows="5" cols="40" name="description"></textarea></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td colspan="3"><input type="submit" value="Add Version"></td>
</tr>
</form>
</table>
